# Collectibles Recognition API Documentation

## Overview

This page describes the **API of Collectibles Recognition** service for images. With this service you can analyse photos of collectible items via AI. The API method first detect all collectible items on a photo and then recognizes their types (Stamp, Coin, Banknote, Comics, Card, Slab Label). For detected Cards (**Trading Card Game** or **Sport Card**) and **Comics** (Manga included), the service can identify `name`, `set`, `series`, `card number`, `year` of release and other fields. For some cards/games it also return IDs for TCG Player. **It can also read information from the Slab Labels or get the prices of the collector items.**

### Quick Links

- [Quickstart Guide](/)
- [Taxonomy](/taxonomy/collectibles)
- [Blog](https://www.ximilar.com/blog/tag/collectibles/)
- [Test in APP](https://app.ximilar.com/tagging/collectibles/overview)
- [Public Demo](https://demo.ximilar.com/collectibles-recognition)

### Access Requirements

> **Note:** In order to get access to the Collectibles Recognition service, please register at https://app.ximilar.com. In the app pick "Ready-To-Use Image Recognition" on the main dashboard and then Collectibles Recognition. **This service is available only in Business and Professional pricing plans**. A public demo is located at [demo.ximilar.com](https://demo.ximilar.com/collectibles-recognition).

### Customization

> **Note:** If you are looking for a more detailed analysis of collector items, e.g.:
> - you are missing a specific feature, items or game and would like to add it to this endpoint,
> - or you want visual search or identification of the stamp, banknotes, coins, comics, posters, vinyl covers, cards, etc.,
> - or you want visual search on your own database of collectors items
> 
> Then please contact us at care@ximilar.com and we can create a customized solution for you.

### Asynchronous API

> **Warning:** This service also supports asynchronous API with webhook. If you need to process large number of requests per day or month (millions of requests) and don't need to get the results immediately then just use our asynchronous requests with webhooks.

## API Endpoints

This service API has several endpoints running at URLs, each suitable for different use cases and priced differently:

```
https://api.ximilar.com/collectibles/v2/tcg_id        (for trading card games)
https://api.ximilar.com/collectibles/v2/sport_id      (for sport cards)
https://api.ximilar.com/collectibles/v2/comics_id     (for comics magazines & books & manga)
https://api.ximilar.com/collectibles/v2/card_ocr_id   (for OCR on cards)
https://api.ximilar.com/collectibles/v2/slab_id       (for graded slabs - complex analysis)
https://api.ximilar.com/collectibles/v2/slab_grade    (for graded slabs - simple analysis)
https://api.ximilar.com/collectibles/v2/detect        (for localization)
https://api.ximilar.com/collectibles/v2/process       (for localization and tags)
https://api.ximilar.com/collectibles/v2/analyze       (for complete analysis)
```

---

## 1. TCG Identification

**Endpoint:** `POST /v2/tcg_id`

Given a list of image records, this method returns identification for largest **Trading Card Game** card that was detected on image. This service is able to further analyze and identify the trading card.

This service can identify cards from more than 15 games including `Pokemon`, `Yugioh!`, `Magic The Gathering`, `OnePiece`, `Lorcana`. The Full list is available on Taxonomy page. It is also able to recognize **Alphabet/Language**, and visual features like **Holo/Foil**, etc. If the input card is from one of mentioned games, then we are able to identify the card set, set_code, series, card_number, full_name, year of release and other fields. For some of these cards and games we have links to `tcgplayer.com`, `scryfall.com` and other sites. It can also detects and analyze the graded `Slab Label` (getting certificate number, grade value..).

> **Note:** If you need to distinguish international/latin alphabet language (English, German, Portuguese, Spanish, ...) send lang: true and in returned _ocr field you will find a proper language identification. For Pokemon and One Piece, we are able to properly identify english, chinese (simplified) and japanese variants of the cards.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Optional Parameters

- **lang** (boolean, default: False): Set true if you need to distinguish language of trading card in latin alphabet, otherwise take the language information from _tags.
- **slab_id** (boolean, default: False): If set to true, then the slab identification will be done via OCR and AI, default False. This will analyse only one slab label on the image and also count additional API credits according to **/v2/slab_id**.
- **slab_grade** (boolean, default: False): If set to true, then AI system will analyse the company and grade on the image, default False. This will also count additional API credits according to **/v2/slab_grade**.
- **analyze_all** (boolean, default: False): If specified it will analyze all cards on image (only 1 record/image is allowed), the perfect use case is a card binder. The number of credits is per number of analysed cards on image instead of records (cards count * credit price of endpoint).
- **pricing** (boolean, default: False): If set to true, then system will try to return the prices, default False. This will also count additional API credits according to pricing operation. The API credits will not be counted if the system return no prices.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by field `_objects` (of type **Slab Label** or **Card**). The main object contains `_identification` with necessary information of identified card.
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/tcg_id \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ],
    "slab_grade": true,
    "slab_id": true,
    "pricing": true
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.tcg_id([
    {"_url": "__PATH_TO_IMAGE_URL__"}
  ],
  slab_grade=True,
  slab_id=True,
  pricing=True
)
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/tcg_id"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ],
  "pricing": True
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

### Optimization Tips

The endpoint can be faster and more accurate if you send Top Category, Category, Side, Alphabet, Subcategory, Foil/Holo and Rotation in the record. The more information you can send the faster and more precise the system is. You can even specify the set_code of the game, in this way the results are restricted on specific game.

```json
{
    "_url": "https://images.ximilar.com/examples/demo/collectibles/gideon.jpeg",
    "Top Category": "Card",
    "Side": "front",
    "Alphabet": "latin",
    "Category": "Card/Trading Card Game",
    "Subcategory": "Magic The Gathering",
    "Foil/Holo": "Non-Foil",
    "Rotation": "rotation_ok",
    "set_code": "CMM"
}
```

---

## 2. Sport Card Identification

**Endpoint:** `POST /v2/sport_id`

Given a list of image records, this method returns identification for largest **Sport Card** detected on image.

This service can identify cards from various sports including `Baseball`, `Basketball`, `Football`, `Hockey`, `Soccer`, and `MMA`. It can also recognize visual features like **Foil/Holo** and **Autograph**. The service provides details such as `name`, `team`, `year`, `card_number`, `set_name`, and `company`.

> **Warning:** Because there are several millions of sports cards and thousands of them are released every month, our database of sport cards is limited and so is our identification. Our database contains several millions of cards and we are constantly working on expanding the database. If you find that we are missing some cards feel free to contact us at tech@ximilar.com.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Optional Parameters

- **slab_id** (boolean, default: False): If set to true, then the slab identification will be done via OCR and AI, default False. This will analyse only one slab label on the image and also count additional API credits according to **/v2/slab_id**.
- **slab_grade** (boolean, default: False): If set to true, then AI system will analyse the company and grade on the image, default False. This will also count additional API credits according to **/v2/slab_grade**.
- **analyze_all** (boolean, default: False): If specified it will analyze all cards on image (only 1 record/image is allowed), the perfect use case is a card binder. The number of credits is per number of analysed cards on image instead of records (cards count * credit price of endpoint).
- **pricing** (boolean, default: False): If set to true, then system will try to return the prices, default False. This will also count additional API credits according to pricing operation. The API credits will not be counted if the system return no prices.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by field `_objects` (of type **Slab Label** or **Card**). The main object contains `_identification` with necessary information of identified card.
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/sport_id \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ],
    "pricing": true
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.sport_id([
    {"_url": "__PATH_TO_IMAGE_URL__"}
  ],
  pricing=True
)
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/sport_id"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ],
  "pricing": True
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 3. Comics Identification

**Endpoint:** `POST /v2/comics_id`

Given a list of images/records, this method returns identification for largest `Comics` detected on image.

This service can identify comics books, comics magazines and manga. This endpoint will tell you `name` of the person, `title`, `date` of release, issue `number`, `publisher` and `origin_date`. We believe that these few informations are enough to precisely identify the comics.

> **Warning:** Because there are several millions of comics and hundreds of them are released every month, our database of comics is limited and so is our identification. We are constantly working on expanding the database. If you find that we are missing some comics feel free to contact us at tech@ximilar.com.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Optional Parameters

- **slab_id** (boolean, default: False): If set to true, then the slab identification will be done via OCR and AI, default False. This will analyse only one slab label on the image and also count additional API credits according to **/v2/slab_id**.
- **slab_grade** (boolean, default: False): If set to true, then AI system will analyse the company and grade on the image, default False. This will also count additional API credits according to **/v2/slab_grade**.
- **analyze_all** (boolean, default: False): If specified it will analyze all comics on image (only 1 record/image is allowed), the number of credits is per number of analysed comics on image instead of records (comics count * credit price of endpoint)
- **pricing** (boolean, default: False): If set to true, then system will try to return the prices, default False. This will also count additional API credits according to pricing operation. The API credits will not be counted if the system return no prices.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by field `_objects` (of type **Slab Label** or **Comics**). The main object contains `_identification` with necessary information of identified comics.
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/comics_id \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ],
    "slab_id": true
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.comics_id([
    {"_url": "__PATH_TO_IMAGE_URL__"}
  ],
  slab_id=True
)
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/comics_id"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ],
  "slab_id": True
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 4. Card OCR & Identification

**Endpoint:** `POST /v2/card_ocr_id`

Given a list of image records, this method returns and identification for largest card detected (and largest slab label if present) on image. This method is suitable for reading text `Cards` and `Slab Labels` (PSA, BECKETT, ...). The identification is done by mining of information from ocr text via AI model (and that is why is sometimes not exactly precise).

Partially correct identification (missing year) for card can look like this:
```json
{
  "name": "ERLING BRAUT HAALAND",
  "year": null,
  "subcategory": "soccer"
}
```

Correct identification for graded slab label can look like this:
```json
{
  "name": "2019 FINEST UEFA ERLING BRAUT HAALAND",
  "grade": "10",
  "year": "2019",
  "certificate_number": "51974133"
}
```

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by field `_objects` (of type **Slab Label** or **Card**). `_objects` (`Card`, `Slab Label`) contains `_ocr`, `_tags`, `_tags_simple` and `_identification`. The `_identification` contains `best_match` field. The identification returns info like `name`, `full_name`, `year`, `grade`, `certificate_number`...
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/card_ocr_id \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ]
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.card_ocr_id([
    {"_url": "__PATH_TO_IMAGE_URL__"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/card_ocr_id"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 5. Slab ID

**Endpoint:** `POST /v2/slab_id`

Given a list of image records, this method returns detected objects (`Card`, `Slab Label`) with OCR analysis. The result `Slab Label` object with `_objects` (`_tags` and `_ocr` included), which represents location of the detected items (and read text). The Slab Label contains information about company/category (`BECKETT`, `CGC`, `PSA`, `SGC`, `ACE`, `MANA`, `TAG`, `OTHER`). For one `Slab Label` per image, this model analyzes read text via AI of the slab and returns the analyzed info in `_identification` field.

> **Note:** If you would like to analyse labels from company which we do not include, feel free to contact us at tech@ximilar.com

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by fields, `Slab Label` and `_objects` with `_tags` and `_ocr`.
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/slab_id \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ]
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.slab_id([
    {"_url": "__PATH_TO_IMAGE_URL__"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/slab_id"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 6. Slab Grade

**Endpoint:** `POST /v2/slab_grade`

Given a list of image records, this method returns detected objects (`Card`, `Slab Label`) with image recognition analysis. The result `Slab Label` object with `_objects` (`_tags` included), which represents location of the detected items (and analysed features - `Company`, `Grade`, `Side`). The Slab Label object contains information about Company/Category (`BECKETT`, `CGC`, `PSA`, `SGC`, `MANA`, `ACE`, `TAG`, `Other`), Grade and Side.

> **Note:** If you would like to analyse labels from company which we do not include, feel free to contact us at tech@ximilar.com

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by fields, `Slab Label` and `_objects` with `_tags`.
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/slab_grade \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ]
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.slab_grade([
    {"_url": "__PATH_TO_IMAGE_URL__"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/slab_grade"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 7. Collectibles Detection

**Endpoint:** `POST /v2/detect`

Given a list of image records, this method returns objects of collector's items for each of them. The result images with `_objects` which represents location of the detected items. This method can be used as a first step for other endpoints as `/v2/tcg_id` if you know that multiple cards are on the image.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by fields (`_objects`).
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/detect \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ]
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.detect([
    {"_url": "__PATH_TO_IMAGE_URL__"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/detect"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 8. Collectibles Process

**Endpoint:** `POST /v2/process`

Given a list of image records, this method returns objects of collector's items for each of them with basic classification. The result images with `_objects` which represents location of the detected items and their basic tags. This method is useful for getting basic information about collectible items on the image.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by fields (`_objects` with basic classification tags).
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl https://api.ximilar.com/collectibles/v2/process \
  -H "Content-Type: application/json" \
  -H "Authorization: Token __API_TOKEN__" \
  -d '{
    "records": [
        {
          "_url": "__PATH_TO_IMAGE_URL__"
        }
    ]
  }'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.process([
    {"_url": "__PATH_TO_IMAGE_URL__"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/process"

payload = json.dumps({
  "records": [
    {
      "_url": "__PATH_TO_IMAGE_URL__"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## 9. Collectibles Analyze

**Endpoint:** `POST /v2/analyze`

Given a list of image records, this method returns complete analysis of collector's items for each of them. The result images with `_objects` which represents location of the detected items, their basic tags, and detailed identification. This method combines detection, classification, and identification in one call.

We recommend to use a specialized endpoint for [TCG ID](#1-tcg-identification), [Sports ID](#2-sport-card-identification) or [Comics ID](#3-comics-identification) if you already know what collectibles you would like to analyze.

### Required Parameters

- **records** (dict): A batch of json records (max 10), one record is representation of an image and it's defined by `_url` or `_base64`.

### Response

HTTP error code 2XX, if the method was OK and other HTTP error code, if the method failed.
Body of the response is a JSON object (map) with the following fields:

- **records** (dict): JSON array with the input `records`, each record enriched by fields (`_objects` with complete analysis including detection, classification tags, and identification).
- **status** (dict): A JSON map/dictionary with a status of the method processing. It contains these subfields: `code` (numeric code of the operation status; it follows the concept of HTTP status codes) and `text` (text describing the status code).

### Example Request

#### cURL
```bash
curl --location 'https://api.ximilar.com/collectibles/v2/analyze' \
--header 'Authorization: Token __API_TOKEN__' \
--header 'Content-Type: application/json' \
--data '{
    "records": [
        {
            "_url": "https://images.ximilar.com/examples/cards/pokemon.jpeg"
        }
    ]
}'
```

#### Python (using Ximilar client)
```python
from ximilar.collectibles import CollectiblesRecognitionClient

client = CollectiblesRecognitionClient(__API_TOKEN__)
client.max_image_size = 0

response = client.analyze([
    {"_url": "https://images.ximilar.com/examples/cards/pokemon.jpeg"}
])
```

#### Python (using requests)
```python
import requests
import json

url = "https://api.ximilar.com/collectibles/v2/analyze"

payload = json.dumps({
  "records": [
    {
      "_url": "https://images.ximilar.com/examples/cards/pokemon.jpeg"
    }
  ]
})
headers = {
  'Authorization': '__API_TOKEN__',
  'Content-Type': 'application/json'
}

response = requests.request("POST", url, headers=headers, data=payload)
```

---

## Support

For any questions or support, please contact us at:
- General inquiries: care@ximilar.com
- Technical support: tech@ximilar.com

## Additional Resources

- [Taxonomy Documentation](/taxonomy/collectibles)
- [Blog Articles](https://www.ximilar.com/blog/tag/collectibles/)
- [Interactive Demo](https://demo.ximilar.com/collectibles-recognition)
- [Application Dashboard](https://app.ximilar.com/tagging/collectibles/overview)
